@@ -192,18 +192,18 @@ class AccelEntry( gobject.GObject ):
 		self.set_accelerator_name(self.__old_value)
 
 class ColorblindPreferencesUI:
-	CB_FILTER_NO_FILTER, CB_FILTER_SELECTIVE_SATURATE_RED, CB_FILTER_SELECTIVE_SATURATE_GREEN, CB_FILTER_SELECTIVE_SATURATE_BLUE, CB_FILTER_SELECTIVE_DESSATURATE_RED, CB_FILTER_SELECTIVE_DESSATURATE_GREEN, CB_FILTER_SELECTIVE_DESSATURATE_BLUE, CB_FILTER_POSITIVE_HUE_SHIFT, CB_FILTER_NEGATIVE_HUE_SHIFT = range (9)
+	CB_FILTER_NO_FILTER, CB_FILTER_SELECTIVE_SATURATE_RED, CB_FILTER_SELECTIVE_SATURATE_GREEN, CB_FILTER_SELECTIVE_SATURATE_BLUE, CB_FILTER_SELECTIVE_DESATURATE_RED, CB_FILTER_SELECTIVE_DESATURATE_GREEN, CB_FILTER_SELECTIVE_DESATURATE_BLUE, CB_FILTER_POSITIVE_HUE_SHIFT, CB_FILTER_NEGATIVE_HUE_SHIFT = range (9)
 
 	def __init__(self, applet):
 		self.glade = gtk.glade.XML(join(colorblind.SHARED_DATA_DIR, "colorblind-prefs.glade"))
-		
+
 		self.dialog = self.glade.get_widget("window_preferences")
 		self.radio1 = self.glade.get_widget("radio_filter_red_saturate")
 		self.radio2 = self.glade.get_widget("radio_filter_green_saturate")
 		self.radio3 = self.glade.get_widget("radio_filter_blue_saturate")
-		self.radio4 = self.glade.get_widget("radio_filter_red_dessaturate")
-		self.radio5 = self.glade.get_widget("radio_filter_green_dessaturate")
-		self.radio6 = self.glade.get_widget("radio_filter_blue_dessaturate")
+		self.radio4 = self.glade.get_widget("radio_filter_red_desaturate")
+		self.radio5 = self.glade.get_widget("radio_filter_green_desaturate")
+		self.radio6 = self.glade.get_widget("radio_filter_blue_desaturate")
 		self.radio7 = self.glade.get_widget("radio_filter_positive_hue_shift")
 		self.radio8 = self.glade.get_widget("radio_filter_negative_hue_shift")
 		self.hbox_default = self.glade.get_widget("hbox_default")
@@ -212,9 +212,9 @@ class ColorblindPreferencesUI:
 		self.combofilters.append_text (_("Selective Red Saturation"))
 		self.combofilters.append_text (_("Selective Green Saturation"))
 		self.combofilters.append_text (_("Selective Blue Saturation"))
-		self.combofilters.append_text (_("Selective Red Dessaturation"))
-		self.combofilters.append_text (_("Selective Green Dessaturation"))
-		self.combofilters.append_text (_("Selective Blue Dessaturation"))
+		self.combofilters.append_text (_("Selective Red Desaturation"))
+		self.combofilters.append_text (_("Selective Green Desaturation"))
+		self.combofilters.append_text (_("Selective Blue Desaturation"))
 		self.combofilters.append_text (_("Positive Hue Shift"))
 		self.combofilters.append_text (_("Negative Hue Shift"))
 		self.check_default_filter = self.glade.get_widget("check_default_filter")
@@ -231,9 +231,11 @@ class ColorblindPreferencesUI:
 		self.keyboard_shortcut_entry_switch.connect('accel-edited', self.on_keyboard_shortcut_entry_changed, colorblind.GCONF_KEYBINDING_SWITCH)
 		self.glade.get_widget("table_shortcut").attach(self.keyboard_shortcut_entry_switch.get_widget(), 1, 2, 1, 2)
 
+		colorblind.GCONF_CLIENT.notify_add (colorblind.GCONF_COLORBLIND_FILTER, self.sync_ui)
 		self.colorblind_filter = colorblind.GCONF_CLIENT.get_int(colorblind.GCONF_COLORBLIND_FILTER)
 		if self.colorblind_filter == None:
 			self.colorblind_filter = self.CB_FILTER_POSITIVE_HUE_SHIFT
+		colorblind.GCONF_CLIENT.notify_add (colorblind.GCONF_DEFAULT_FILTER, self.sync_ui)
 		self.default_filter = colorblind.GCONF_CLIENT.get_int(colorblind.GCONF_DEFAULT_FILTER)
 		if self.colorblind_filter == None:
 			self.colorblind_filter = self.CB_FILTER_POSITIVE_HUE_SHIFT
@@ -253,11 +255,11 @@ class ColorblindPreferencesUI:
 		elif entry == self.radio3:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_BLUE)
 		elif entry == self.radio4:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_RED)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_RED)
 		elif entry == self.radio5:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_GREEN)
 		elif entry == self.radio6:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_BLUE)
 		elif entry == self.radio7:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_POSITIVE_HUE_SHIFT)
 		elif entry == self.radio8:
@@ -272,12 +274,12 @@ class ColorblindPreferencesUI:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_GREEN)
 		elif i == self.CB_FILTER_SELECTIVE_SATURATE_BLUE:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_BLUE)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_RED:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_RED)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_RED:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_RED)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_GREEN:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_GREEN)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_BLUE:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_BLUE)
 		elif i == self.CB_FILTER_POSITIVE_HUE_SHIFT:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_POSITIVE_HUE_SHIFT)
 		elif i == self.CB_FILTER_NEGATIVE_HUE_SHIFT:
@@ -288,9 +290,14 @@ class ColorblindPreferencesUI:
 		colorblind.GCONF_CLIENT.set_bool(colorblind.GCONF_CHECK_DEFAULT, state)
 
 	def __on_click_button_close_event (self, entry):
+		self.dialog.emit ('delete-event', gtk.gdk.Event (gtk.gdk.DELETE))
+
+	def __on_dialog_delete_event (self, entry, *extra):
 		self.dialog.destroy ()
+		colorblind.ColorblindApplet.pref_ui_unmapped ()
 
 	def set_ui_signals (self):
+		self.dialog.connect('delete-event', self.__on_dialog_delete_event)
 		self.radio1.connect('toggled', self.__on_radio_toggled_event)
 		self.radio2.connect('toggled', self.__on_radio_toggled_event)
 		self.radio3.connect('toggled', self.__on_radio_toggled_event)
@@ -309,6 +316,7 @@ class ColorblindPreferencesUI:
 		self.sync_ui ()
 		self.dialog.set_screen(parent.get_screen())
 		self.dialog.show_all ()
+		self.mapped = True
 
 	def get_on_off_entry (self):
 		return self.keyboard_shortcut_entry_on_off
@@ -316,7 +324,7 @@ class ColorblindPreferencesUI:
 	def get_switch_entry (self):
 		return self.keyboard_shortcut_entry_switch
 	
-	def sync_ui(self):
+	def sync_ui(self, *extra):
 		if self.keybinding_on_off != None:
 			self.keyboard_shortcut_entry_on_off.set_accelerator_name(self.keybinding_on_off)
 		else:
@@ -326,7 +334,9 @@ class ColorblindPreferencesUI:
 		else:
 			self.keyboard_shortcut_entry_switch.set_accelerator_name("<Shift><Control>n")
 
-		self.colorblind_filter = colorblind.GCONF_CLIENT.get_int(colorblind.GCONF_COLORBLIND_FILTER)
+		self.colorblind_filter = colorblind.GCONF_CLIENT.get_int (colorblind.GCONF_COLORBLIND_FILTER)
+		self.default_filter = colorblind.GCONF_CLIENT.get_int (colorblind.GCONF_DEFAULT_FILTER)
+		self.check_default = colorblind.GCONF_CLIENT.get_bool (colorblind.GCONF_CHECK_DEFAULT)
 
 		if self.colorblind_filter == 1:
 			self.radio1.set_active (True)
