@@ -21,19 +21,22 @@
  */
 
 #include "config.h"
-#include <string.h>
-#include <stdlib.h>
-#include <sys/time.h>
-#include <gdk/gdkwindow.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
-#include <libbonobo.h>
 #include "magnifier.h"
 #include "magnifier-private.h"
 #include "zoom-region.h"
-#include "gmag-events.h"
+#include "gmag-graphical-server.h"
 #include "GNOME_Magnifier.h"
 
+#include <string.h>
+#include <stdlib.h>
+#include <sys/time.h>
+
+#include <gdk/gdkwindow.h>
+#include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+
+#include <libbonobo.h>
+
 #define ENV_STRING_MAX_SIZE 128
 
 GNOME_Magnifier_ZoomRegion zoom_region;
@@ -72,6 +75,8 @@ typedef struct {
 	gboolean   ignore_composite;
 #endif /* HAVE_COMPOSITE */
 	gboolean  print_version;
+	gboolean  hide_pointer;
+	gboolean  show_crosswires;
 } MagnifierOptions;
 
 static MagnifierOptions global_options = { NULL,      /* target_display */
@@ -106,7 +111,9 @@ static MagnifierOptions global_options = { NULL,      /* target_display */
 #ifdef HAVE_COMPOSITE
 					   ,0         /* ignore_composite */
 #endif /* HAVE_COMPOSITE */
-					   ,0         /* print_version */
+					   ,0,        /* print_version */
+					   0,         /* hide_pointer */
+					   0          /* show_crosswires */ 
                                          };
 
 static GOptionEntry magnifier_options [] = {
@@ -134,13 +141,15 @@ static GOptionEntry magnifier_options [] = {
 	{"smooth-scrolling", 0, 0, G_OPTION_ARG_NONE, &global_options.smooth_scroll, "use smooth scrolling", NULL},
 	{"border-size", 'b', 0, G_OPTION_ARG_INT, &global_options.border_width, "width of border", NULL},
 	{"border-color", 'c', 0, G_OPTION_ARG_INT64, &global_options.border_color, "border color specified as (A)RGB 23-bit value, Alpha-MSB", NULL},
+	{"hide-pointer", 0, 0, G_OPTION_ARG_NONE, &global_options.hide_pointer, "hide magnifier pointer when passed", NULL},
+	{"show-crosswires", 0, 0, G_OPTION_ARG_NONE, &global_options.show_crosswires, "show crosswires when passed", NULL},
 	{"use-test-pattern", 0, 0, G_OPTION_ARG_NONE, &global_options.test_pattern, "use test pattern as source", NULL},
 	{"override-redirect", 0, 0, G_OPTION_ARG_NONE, &global_options.is_override_redirect, "make the magnifier window totally unmanaged by the window manager", NULL},
 	{"ignore-damage", 0, 0, G_OPTION_ARG_NONE, &global_options.ignore_damage, "ignore the X server DAMAGE extension, if present", NULL},
 #ifdef HAVE_COMPOSITE
 	{"ignore-composite", 0, 0, G_OPTION_ARG_NONE, &global_options.ignore_composite, "ignore the X server COMPOSITE extension, if present", NULL},
 #endif /* HAVE_COMPOSITE */
-	{"version", 'v', 0, G_OPTION_ARG_NONE, &global_options.print_version, "print version", NULL},
+	{"version", 0, 0, G_OPTION_ARG_NONE, &global_options.print_version, "print version", NULL},
 	{NULL}
 };
 
@@ -154,7 +163,7 @@ init_rect_bounds (GNOME_Magnifier_RectBounds *bounds,
 	bounds->y2 = y2;
 }
 
-static int screen_width, screen_height;
+static int target_width, target_height;
 
 static int
 magnifier_main_test_image (gpointer data)
@@ -188,11 +197,11 @@ magnifier_main_test_image (gpointer data)
 
 	x_roi  = global_options.timing_delta_x * timing_x_pos;
 	roi.x1 = x_roi;
-	roi.x2 = (screen_width / global_options.zoom_factor) + roi.x1;
+	roi.x2 = (target_width / global_options.zoom_factor) + roi.x1;
 	x_roi  = global_options.timing_delta_x * (timing_x_pos + x_direction);
 
 	/* Determine if magnifier hit an edge and should reverse direction */
-	if (x_roi + (screen_width / global_options.zoom_factor) > screen_width)
+	if (x_roi + (target_width / global_options.zoom_factor) > target_width)
 		x_direction = -1;
 	else if (x_roi < 0)
 		x_direction = 1;
@@ -203,15 +212,16 @@ magnifier_main_test_image (gpointer data)
 
 	/* Calculate size of screen not covered by magnifier */
 	if (global_options.horizontal_split)
-		roi.y1 = y_roi + screen_height;
+		roi.y1 = y_roi + target_height;
 	else
 		roi.y1 = y_roi;
-	roi.y2 = (screen_height / global_options.zoom_factor) + roi.y1;
+	roi.y2 = (target_height / global_options.zoom_factor) + roi.y1;
 
 	y_roi = global_options.timing_delta_y * (timing_y_pos + y_direction);
 
 	/* The counter is increased each time the y-direction changes */
-	if (y_roi + (screen_height / global_options.zoom_factor) > screen_height) {
+	if (y_roi + (target_height / global_options.zoom_factor) >
+	    target_height) {
 		timing_counter++;
 		y_direction = -1;
 	}
@@ -359,7 +369,7 @@ main (int argc, char** argv)
   GNOME_Magnifier_RectBounds *roi = GNOME_Magnifier_RectBounds__alloc();
   GNOME_Magnifier_RectBounds *viewport = GNOME_Magnifier_RectBounds__alloc();
   CORBA_any *viewport_any;
-  int x = 0, y = 0, fullwidth, fullheight;
+  int x = 0, y = 0, src_width, src_height;
   guint pan_handle = 0, refresh_handle = 0;
   CORBA_Environment ev;
   Bonobo_PropertyBag properties;
@@ -417,7 +427,9 @@ main (int argc, char** argv)
       g_setenv ("MAGNIFIER_IGNORE_DAMAGE", "1", TRUE);
   }
 #ifdef HAVE_COMPOSITE
-  if (global_options.ignore_composite) {
+  if (global_options.ignore_composite || (
+	      strcmp (global_options.target_display,
+		      global_options.source_display) != 0)) {
 	  g_setenv ("MAGNIFIER_IGNORE_COMPOSITE", "1", TRUE);
   }
 #endif /* HAVE_COMPOSITE */
@@ -456,49 +468,67 @@ main (int argc, char** argv)
 				     global_options.cursor_color, 
 				     NULL);
 
-  fullwidth = screen_width = gdk_screen_get_width (
-	  gdk_display_get_screen (magnifier->target_display,
-				  magnifier->target_screen_num));
-  fullheight = screen_height = gdk_screen_get_height (
+  if (!global_options.show_crosswires)
+	  bonobo_pbclient_set_long (properties, "crosswire-size", 0, NULL);
+
+  src_width = gdk_screen_get_width (gdk_display_get_screen (
+					    magnifier->source_display,
+					    magnifier->source_screen_num));
+  src_height = gdk_screen_get_height (gdk_display_get_screen (
+					      magnifier->source_display,
+					      magnifier->source_screen_num));
+
+  target_width = gdk_screen_get_width (gdk_display_get_screen (
+					       magnifier->target_display,
+					       magnifier->target_screen_num));
+  target_height = gdk_screen_get_height (
 	  gdk_display_get_screen (magnifier->target_display,
 				  magnifier->target_screen_num));
 
   if (global_options.vertical_split) {
-	  screen_width /= 2;
-	  x = screen_width;
+	  target_width /= 2;
+	  x = target_width;
   }
   if (global_options.horizontal_split) {
-	  screen_height /= 2;
-	  y = screen_height;
+	  target_height /= 2;
+	  y = target_height;
   }
 
-  fprintf (stderr, "initial viewport %d %d\n", (int) screen_width,
-	   (int) screen_height);
+  fprintf (stderr, "initial viewport %d %d\n", (int) target_width,
+	   (int) target_height);
 
-  init_rect_bounds (viewport, x, y, x + screen_width, y + screen_height);
-  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds, viewport);
   
-  bonobo_pbclient_set_value (properties, "target-display-bounds",
-			     viewport_any,
-			     &ev);
-  bonobo_arg_release (viewport_any);
+  if (global_options.vertical_split || global_options.horizontal_split ||
+      global_options.fullscreen) {
+	  init_rect_bounds (viewport, x, y, x + target_width,
+			    y + target_height);
+	  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds,
+					      viewport);
+  
+	  bonobo_pbclient_set_value (properties, "target-display-bounds",
+				     viewport_any, &ev);
+	  bonobo_arg_release (viewport_any);
+  }
 
   if (global_options.vertical_split || global_options.horizontal_split) 
   {
 #ifdef HAVE_COMPOSITE
 	  if (!g_getenv ("MAGNIFIER_IGNORE_COMPOSITE"))
-		  init_rect_bounds (viewport, 0, 0, fullwidth, fullheight);
+		  init_rect_bounds (viewport, 0, 0,
+				    src_width, src_height);
 	  else
 #endif /* HAVE_COMPOSITE */
-		  init_rect_bounds (viewport, 0, 0, fullwidth-x, fullheight-y);
-      viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds, viewport);
+		  init_rect_bounds (viewport, 0, 0,
+				    src_width-x, src_height-y);
+      viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds,
+					  viewport);
       bonobo_pbclient_set_value (properties, "source-display-bounds",
 				 viewport_any,
 				 &ev);
 
       bonobo_arg_release (viewport_any);
   } else if (global_options.fullscreen) {
-	  init_rect_bounds (viewport, 0, 0, fullwidth, fullheight);
+	  init_rect_bounds (viewport, 0, 0, src_width, src_height);
 	  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds,
 					      viewport);
 	  bonobo_pbclient_set_value (properties, "source-display-bounds",
@@ -516,8 +546,10 @@ main (int argc, char** argv)
   {
 	  int scroll_policy;
 	  
-	  init_rect_bounds (roi, 0, 0, 100, 100);
-	  init_rect_bounds (viewport, 0, 0, screen_width, screen_height);
+	  init_rect_bounds (roi, 0, 0,
+			    target_width / global_options.zoom_factor,
+			    target_height / global_options.zoom_factor);
+	  init_rect_bounds (viewport, 0, 0, target_width, target_height);
 	  zoom_region =
 		  GNOME_Magnifier_Magnifier_createZoomRegion (
 			  BONOBO_OBJREF (magnifier),
@@ -549,6 +581,8 @@ main (int argc, char** argv)
 				       (short) scroll_policy, &ev);
 	  bonobo_pbclient_set_boolean (properties, "use-test-pattern",
 				       global_options.test_pattern, &ev);
+	  bonobo_pbclient_set_boolean (properties, "draw-cursor",
+				       !global_options.hide_pointer, &ev);
 
 	  if (strcmp (global_options.smoothing_type, "none"))
 		  bonobo_pbclient_set_string (properties, "smoothing-type",
@@ -572,9 +606,9 @@ main (int argc, char** argv)
 	  GNOME_Magnifier_ZoomRegionList *zoom_regions;
 	  GNOME_Magnifier_RectBounds roi;
 	  roi.x1 = 100;
-	  roi.x2 = 100 + (screen_width / global_options.zoom_factor);
+	  roi.x2 = 100 + (target_width / global_options.zoom_factor);
 	  roi.y1 = 0;
-	  roi.y2 = screen_height / global_options.zoom_factor;
+	  roi.y2 = target_height / global_options.zoom_factor;
 	  
 	  zoom_regions = GNOME_Magnifier_Magnifier_getZoomRegions (
 		  BONOBO_OBJREF (magnifier), &ev);
@@ -594,7 +628,7 @@ main (int argc, char** argv)
   else
   {
 	  if (global_options.ignore_damage ||
-	      !gmag_events_source_has_damage_extension (magnifier)) 
+	      !gmag_gs_source_has_damage_extension (magnifier)) 
 	  {
 	  	  refresh_handle = g_timeout_add (
 	  		  global_options.refresh_time,
